==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/DefaultMethodOptimizer__24Inline.h <==
// class org.dellroad.jc.cgen.DefaultMethodOptimizer$Inline

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9d8931f65478575d org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_
#define _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object;

typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$_init$b35ca33bce9a8491(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_soot_SootClass$object *_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$getStaticInvokeClass$233c4a112e06e840(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *);
extern jboolean _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$tooBig$df6266ba0772b2d0(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method_info$getStaticInvokeClass$233c4a112e06e840;
extern _jc_method _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method_info$tooBig$df6266ba0772b2d0;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods {
	struct _jc_soot_SootClass$object	*(*getStaticInvokeClass$233c4a112e06e840)(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *);
	jboolean	(*tooBig$df6266ba0772b2d0)(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, jint);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs {
	struct _jc_soot_SootMethod$object	*caller;
	struct _jc_soot_SootMethod$object	*callee;
	struct _jc_object	*expr;
	struct _jc_object	*stmt;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs {
    _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs {
	jint	calleeSize;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object {
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/DefaultMethodOptimizer__24Inline.h <==
// class org.dellroad.jc.cgen.DefaultMethodOptimizer$Inline

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9d8931f65478575d org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_
#define _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_InvokeExpr$object;
struct _jc_soot_jimple_Stmt$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object;

typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$_init$b35ca33bce9a8491(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_SootClass$object *_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$getStaticInvokeClass$233c4a112e06e840(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method$tooBig$df6266ba0772b2d0(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method_info$getStaticInvokeClass$233c4a112e06e840;
extern _jc_method _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$method_info$tooBig$df6266ba0772b2d0;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods {
	struct _jc_soot_SootClass$object	*(*getStaticInvokeClass$233c4a112e06e840)(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *) _JC_JCNI_ATTR;
	jboolean	(*tooBig$df6266ba0772b2d0)(_jc_env *, struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vmethods	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs {
	struct _jc_soot_SootMethod$object	*caller;
	struct _jc_soot_SootMethod$object	*callee;
	struct _jc_object	*expr;
	struct _jc_object	*stmt;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs {
    _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_refs	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs {
	jint	calleeSize;
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$sub_nonrefs	org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$object {
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$vtype _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_DefaultMethodOptimizer__24Inline_H_ */
